@@ -13,6 +13,7 @@ declare(strict_types=1);
 
 namespace League\CommonMark\Tests\Unit\Util;
 
+use League\CommonMark\Exception\InvalidArgumentException;
 use League\CommonMark\Extension\CommonMark\Node\Block\HtmlBlock;
 use League\CommonMark\Util\RegexHelper;
 use PHPUnit\Framework\TestCase;
@@ -295,7 +296,7 @@ final class RegexHelperTest extends TestCase
     /**
      * @return iterable<array<mixed>>
      */
-    public function dataForTestMatchAt(): iterable
+    public static function dataForTestMatchAt(): iterable
     {
         return [
             ['/ /', 'foo bar', null, 3],
@@ -328,7 +329,7 @@ final class RegexHelperTest extends TestCase
     /**
      * @return iterable<int>
      */
-    public function blockTypesWithValidOpenerRegexes(): iterable
+    public static function blockTypesWithValidOpenerRegexes(): iterable
     {
         yield [HtmlBlock::TYPE_1_CODE_CONTAINER];
         yield [HtmlBlock::TYPE_2_COMMENT];
@@ -341,7 +342,7 @@ final class RegexHelperTest extends TestCase
 
     public function testInvalidHtmlBlockOpenRegex(): void
     {
-        $this->expectException(\InvalidArgumentException::class);
+        $this->expectException(InvalidArgumentException::class);
 
         RegexHelper::getHtmlBlockOpenRegex(8);
     }
@@ -357,7 +358,7 @@ final class RegexHelperTest extends TestCase
     /**
      * @return iterable<int>
      */
-    public function blockTypesWithValidCloserRegexes(): iterable
+    public static function blockTypesWithValidCloserRegexes(): iterable
     {
         yield [HtmlBlock::TYPE_1_CODE_CONTAINER];
         yield [HtmlBlock::TYPE_2_COMMENT];
@@ -371,7 +372,7 @@ final class RegexHelperTest extends TestCase
      */
     public function testInvalidHtmlBlockCloseRegex(int $type): void
     {
-        $this->expectException(\InvalidArgumentException::class);
+        $this->expectException(InvalidArgumentException::class);
 
         RegexHelper::getHtmlBlockCloseRegex($type);
     }
@@ -379,7 +380,7 @@ final class RegexHelperTest extends TestCase
     /**
      * @return iterable<int>
      */
-    public function blockTypesWithInvalidCloserRegexes(): iterable
+    public static function blockTypesWithInvalidCloserRegexes(): iterable
     {
         yield [HtmlBlock::TYPE_6_BLOCK_ELEMENT];
         yield [HtmlBlock::TYPE_7_MISC_ELEMENT];
